@@ -558,8 +558,8 @@ class FrameBaseHandler(BaseApiHandler):
         :return int
         :last_editors: HuangJianYi
         """
-        act_id = self.get_param_int("act_id",0)
-        if act_id > 0:
+        act_id = self.get_param_int("act_id",-1)
+        if act_id >= 0:
             return act_id
         app_id = self.get_app_id()
         env = self.get_param("env") if self.get_param("env") else config.get_value("env","")
