@@ -249,7 +249,12 @@ class GetHighPowerListHandler(ClientBaseHandler):
         access_token = self.get_access_token()
         top_base_model = TopBaseModel(context=self)
         mp_base_model = MPBaseModel(context=self)
-        custom_function_list = mp_base_model.get_custom_function_list(store_user_nick)
+        # 如果登录账号的主账号等于配置文件指定的测试账号，则取子账号进行权限的获取，方便不同子账号进到不同的SaaS定制
+        test_config = share_config.get_value("test_config", {})
+        if store_user_nick and store_user_nick == test_config.get("user_nick", ""):
+            custom_function_list = mp_base_model.get_custom_function_list(user_nick)
+        else:
+            custom_function_list = mp_base_model.get_custom_function_list(store_user_nick)
         config_data_list = []
         if len(custom_function_list) == 0:
             config_data = {}
