@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 11:03:56
-@LastEditTime: 2022-10-21 11:21:20
+@LastEditTime: 2023-01-12 09:44:36
 @LastEditors: HuangJianYi
 @Description: ip模块
 """
@@ -49,7 +49,7 @@ class SaveIpInfoHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "IP；"
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "IP"
         ip_base_model = IpBaseModel(context=self)
         invoke_result_data = ip_base_model.save_ip_info(app_id, act_id, ip_id, ip_name, ip_pic, show_pic, sort_index, is_release, ip_type, ip_summary, mode_type, ip_config_json)
         if invoke_result_data.success ==False:
@@ -58,7 +58,7 @@ class SaveIpInfoHandler(ClientBaseHandler):
             # 记录日志
             self.create_operation_log(operation_type=OperationType.add.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=None, update_detail=invoke_result_data.data["new"], title= title_prefix + ip_name)
         else:
-            self.create_operation_log(operation_type=OperationType.update.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title= title_prefix + ip_name)
+            self.create_operation_log(operation_type=OperationType.update.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title= title_prefix + ";" + ip_name)
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -123,12 +123,12 @@ class DeleteIpInfoHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "IP；"
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "IP"
         ip_base_model = IpBaseModel(context=self)
         invoke_result_data = ip_base_model.update_ip_info_status(app_id, ip_id, 1)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(operation_type=OperationType.delete.value, model_name="ip_info_tb", title= title_prefix + invoke_result_data.data["ip_name"])
+        self.create_operation_log(operation_type=OperationType.delete.value, model_name="ip_info_tb", title= title_prefix + ";" + invoke_result_data.data["ip_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -157,13 +157,13 @@ class ReleaseIpInfoHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "IP；"
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "IP"
         ip_base_model = IpBaseModel(context=self)
         invoke_result_data = ip_base_model.release_ip_info(app_id, ip_id, is_release)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         operation_type = OperationType.release.value if is_release == 1 else OperationType.un_release.value
-        self.create_operation_log(operation_type=operation_type, model_name="ip_info_tb", title= title_prefix + invoke_result_data.data["ip_name"])
+        self.create_operation_log(operation_type=operation_type, model_name="ip_info_tb", title= title_prefix + ";" + invoke_result_data.data["ip_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -200,16 +200,16 @@ class SaveIpTypeHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "IP类型；"
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "IP类型"
         ip_base_model = IpBaseModel(context=self)
         invoke_result_data = ip_base_model.save_ip_type(app_id, act_id, ip_type_id, type_name, sort_index, is_release, type_pic)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if invoke_result_data.data["is_add"] == True:
             # 记录日志
-            self.create_operation_log(operation_type=OperationType.add.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=None, update_detail=invoke_result_data.data["new"], title= title_prefix + type_name)
+            self.create_operation_log(operation_type=OperationType.add.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=None, update_detail=invoke_result_data.data["new"], title= title_prefix + ";" + type_name)
         else:
-            self.create_operation_log(operation_type=OperationType.update.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title= title_prefix + type_name)
+            self.create_operation_log(operation_type=OperationType.update.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title= title_prefix + ";" + type_name)
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -274,13 +274,13 @@ class ReleaseIpTypeHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "IP类型；"
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "IP类型"
         ip_base_model = IpBaseModel(context=self)
         invoke_result_data = ip_base_model.release_ip_type(app_id, ip_type_id, is_release)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         operation_type = OperationType.release.value if is_release == 1 else OperationType.un_release.value
-        self.create_operation_log(operation_type=operation_type, model_name="ip_type_tb", title= title_prefix + invoke_result_data.data["type_name"])
+        self.create_operation_log(operation_type=operation_type, model_name="ip_type_tb", title= title_prefix + ";" + invoke_result_data.data["type_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
