@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-10 10:05:38
-@LastEditTime: 2022-10-27 14:22:00
+@LastEditTime: 2023-01-12 09:51:44
 @LastEditors: HuangJianYi
 @Description: 任务模块
 """
@@ -63,7 +63,7 @@ class SaveTaskInfoHandler(ClientBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if not invoke_result_data.data:
             invoke_result_data.data = {}
-        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "任务；"
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "任务"
         operate_user_id = invoke_result_data.data["operate_user_id"] if invoke_result_data.data.__contains__("operate_user_id") else ""
         operate_user_name = invoke_result_data.data["operate_user_name"] if invoke_result_data.data.__contains__("operate_user_name") else ""
         operate_role_id = invoke_result_data.data["operate_role_id"] if invoke_result_data.data.__contains__("operate_role_id") else ""
@@ -81,8 +81,14 @@ class SaveTaskInfoHandler(ClientBaseHandler):
             complete_type = int(item["complete_type"]) if item.__contains__("complete_type") else 1
             sort_index = int(item["sort_index"]) if item.__contains__("sort_index") else 0
             is_release = int(item["is_release"]) if item.__contains__("is_release") else 0
+            route_url = item["route_url"] if item.__contains__("route_url") else ''
+            i1 = int(item["i1"]) if item.__contains__("i1") else 0
+            i2 = int(item["i2"]) if item.__contains__("i2") else 0
+            s1 = item["s1"] if item.__contains__("s1") else ''
+            s2 = item["s2"] if item.__contains__("s2") else ''
             config_json = SevenHelper.json_dumps(item["config_json"]) if item.__contains__("config_json") else {}
-            title = title_prefix + task_name if title_prefix else task_name
+            title = title_prefix + ";" + task_name if title_prefix else task_name
+            now_datetime = SevenHelper.get_now_datetime()
             if "id" in item.keys():
                 task_info = task_info_model.get_entity_by_id(int(item["id"]))
                 if task_info:
@@ -93,8 +99,13 @@ class SaveTaskInfoHandler(ClientBaseHandler):
                     task_info.config_json = config_json
                     task_info.sort_index = sort_index
                     task_info.is_release = is_release
-                    task_info.modify_date = SevenHelper.get_now_datetime()
-                    task_info_model.update_entity(task_info, "complete_type,task_name,sort_index,is_release,config_json,modify_date")
+                    task_info.route_url = route_url
+                    task_info.i1 = i1
+                    task_info.i2 = i2
+                    task_info.s1 = s1
+                    task_info.s2 = s2
+                    task_info.modify_date = now_datetime
+                    task_info_model.update_entity(task_info, "complete_type,task_name,sort_index,is_release,route_url,i1,i2,s1,s2,config_json,modify_date")
                     task_base_model._delete_task_info_dependency_key(0,task_info.id)
                     self.create_operation_log(operation_type=OperationType.update.value, model_name=task_info.__str__(), old_detail=old_task_info.__dict__, update_detail=task_info.__dict__, title=title, operate_user_id=operate_user_id, operate_user_name=operate_user_name, operate_role_id=operate_role_id)
                     ref_params = {}
@@ -110,8 +121,13 @@ class SaveTaskInfoHandler(ClientBaseHandler):
                 task_info.config_json = config_json
                 task_info.sort_index = sort_index
                 task_info.is_release = is_release
-                task_info.create_date = SevenHelper.get_now_datetime()
-                task_info.modify_date = SevenHelper.get_now_datetime()
+                task_info.route_url = route_url
+                task_info.i1 = i1
+                task_info.i2 = i2
+                task_info.s1 = s1
+                task_info.s2 = s2
+                task_info.create_date = now_datetime
+                task_info.modify_date = now_datetime
                 task_info_model.add_entity(task_info)
                 self.create_operation_log(operation_type=OperationType.add.value, model_name=task_info.__str__(), old_detail=None, update_detail=task_info.__dict__, title=title, operate_user_id=operate_user_id, operate_user_name=operate_user_name, operate_role_id=operate_role_id)
                 ref_params = {}
