@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2022-12-01 11:30:13
+@LastEditTime: 2023-03-03 11:54:17
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -23,19 +23,13 @@ class OSS2Helper:
 
     @classmethod
     def get_oss_config(self):
-        oss_config = share_config.get_value("oss_config")
-        if not oss_config:
-            oss_config = {}
-            oss_config["ak_id"] = "LTAI4GAV8q6wxi2gqispR4my"
-            oss_config["ak_secret"] = "LWBuIALo4X4pnBDCwiuRjZur1Yhm5h"
-            oss_config["bucket_name"] = "mang-he"
-            oss_config["end_point"] = "oss-cn-zhangjiakou.aliyuncs.com"
-            oss_config["demain"] = "https://mang-he.oss-cn-zhangjiakou.aliyuncs.com/"
+        oss_config = share_config.get_value("oss_config",{})
         self.ak_id = oss_config.get("ak_id","")
         self.ak_secret = oss_config.get("ak_secret","")
         self.bucket_name = oss_config.get("bucket_name","")
         self.end_point = oss_config.get("end_point","")
         self.demain = oss_config.get("demain","")
+        self.folder = oss_config.get("folder", "")
 
     @classmethod
     def upload(self, file_name, local_file='', folder='', is_auto_name=True, data=None):
@@ -59,7 +53,8 @@ class OSS2Helper:
 
         auth = oss2.Auth(self.ak_id, self.ak_secret)
         bucket = oss2.Bucket(auth, self.end_point, self.bucket_name)
-
+        if not folder:
+            folder = self.folder
         folder = folder.strip('/')
         folder = folder + "/" if folder != "" else folder
         file_name = folder + file_name
