@@ -2,13 +2,14 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-30 09:22:51
-@LastEditTime: 2022-09-27 15:08:55
+@LastEditTime: 2023-02-10 09:55:45
 @LastEditors: HuangJianYi
 @Description: 排队系统帮助类
 """
 from seven_framework import *
 from seven_cloudapp_frame.models.seven_model import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
+from seven_cloudapp_frame.libs.common import *
 
 
 class QueueUpHelper:
@@ -368,18 +369,18 @@ class QueueUpHelper:
                                     is_delete = True
                                     self.logger_info.info("【踢掉办理用户1】" + SevenHelper.json_dumps({"zset_name": zset_name, "first_hash_value": first_hash_value, "user_id": data, "now_timestamp": now_timestamp, "pop_timestamp": hash_value["end_timestamp"]}))
                             elif first_is_process == True and i > 0:
-                                if now_timestamp > first_end_timestamp + (i * int(config.get_value("queue_confirm_time", 8))):
+                                if now_timestamp > first_end_timestamp + (i * int(share_config.get_value("queue_confirm_time", 8))):
                                     is_delete = True
-                                    self.logger_info.info("【踢掉办理用户2】" + SevenHelper.json_dumps({"zset_name": zset_name, "first_hash_value": first_hash_value, "user_id": data, "now_timestamp": now_timestamp, "pop_timestamp": first_end_timestamp + (i * int(config.get_value("queue_confirm_time", 8)))}))
+                                    self.logger_info.info("【踢掉办理用户2】" + SevenHelper.json_dumps({"zset_name": zset_name, "first_hash_value": first_hash_value, "user_id": data, "now_timestamp": now_timestamp, "pop_timestamp": first_end_timestamp + (i * int(share_config.get_value("queue_confirm_time", 8)))}))
                             else:
                                 pop_timestamp = redis_init.hget(self._get_popdate_hash_name(app_id), zset_name)
                                 if pop_timestamp:
                                     pop_timestamp = int(pop_timestamp)
                                 else:
                                     pop_timestamp = hash_value["queue_timestamp"]
-                                if now_timestamp > pop_timestamp + ((i + 1) * int(config.get_value("queue_confirm_time", 8))):
+                                if now_timestamp > pop_timestamp + ((i + 1) * int(share_config.get_value("queue_confirm_time", 8))):
                                     is_delete = True
-                                    self.logger_info.info("【踢掉办理用户3】" + SevenHelper.json_dumps({"zset_name": zset_name, "first_hash_value": first_hash_value, "user_id": data, "now_timestamp": now_timestamp, "pop_timestamp": pop_timestamp + ((i + 1) * int(config.get_value("queue_confirm_time", 8)))}))
+                                    self.logger_info.info("【踢掉办理用户3】" + SevenHelper.json_dumps({"zset_name": zset_name, "first_hash_value": first_hash_value, "user_id": data, "now_timestamp": now_timestamp, "pop_timestamp": pop_timestamp + ((i + 1) * int(share_config.get_value("queue_confirm_time", 8)))}))
 
                         if is_delete == True:
                             self._set_last_pop_date(app_id, redis_init, zset_name)
@@ -637,7 +638,7 @@ class QueueUpHelper:
                     invoke_result_data.error_message = "前面还有人在排队,请耐心等待"
                     return invoke_result_data
                 start_timestamp = TimeHelper.get_now_timestamp()
-                end_timestamp = start_timestamp + int(config.get_value("queue_operate_time", 300))  #操作时间，单位秒
+                end_timestamp = start_timestamp + int(share_config.get_value("queue_operate_time", 300))  #操作时间，单位秒
                 hash_name = self._get_user_hash_name(app_id)
                 hash_key = f"userid_{data}_queuename_{queue_name}"
                 hash_value = redis_init.hget(hash_name, hash_key)
