@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2022-03-10 14:05:22
-@LastEditTime: 2022-07-22 18:11:41
+@LastEditTime: 2023-03-23 18:35:44
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -15,18 +15,15 @@ class RedisExHelper:
     :description: redis帮助类
     """
     @classmethod
-    def init(self, db=None, config_dict=None, decode_responses=True):
+    def init(self, config_dict=None, decode_responses=True):
         """
         :description: redis初始化
         :return: redis_cli
         :last_editors: HuangJianYi
         """
-        host = config.get_value("redis")["host"]
-        port = config.get_value("redis")["port"]
-        if not db:
-            db = config.get_value("redis")["db"]
-        password = config.get_value("redis")["password"]
-        redis_cli = RedisHelper.redis_init(host, port, db, password, config_dict=config_dict, decode_responses=decode_responses)
+        if not config_dict:
+            config_dict = config.get_value("redis")
+        redis_cli = RedisHelper.redis_init(config_dict=config_dict, decode_responses=decode_responses)
         return redis_cli
 
     @classmethod
