@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2023-02-15 13:48:06
+@LastEditTime: 2023-03-10 15:36:33
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -60,17 +60,18 @@ class AssetBaseModel():
             redis_init.hincrby(hash_name_2, str(SevenHelper.get_now_int(fmt='%Y%m%d%H%M')), 1)
             redis_init.expire(hash_name_2, 24 * 3600)
 
-    def delete_asset_only(self, act_id, only_id, create_day=0):
+    def delete_asset_only(self, act_id, only_id, create_day=0, app_id=''):
         """
         :description: 清除资产唯一标识 从数据库和redis中删除
         :param act_id：活动标识
         :param only_id：资产唯一标识
         :param create_day：整形的创建天20200506
+        :param app_id：应用标识
         :return: 
         :last_editors: HuangJianYi
         """
         redis_init = SevenHelper.redis_init()
-        hash_name = f"asset_only_list:{act_id}"
+        hash_name = f"asset_only_list:{act_id}" if act_id > 0 else f"asset_only_list:{app_id}_0"
         if create_day <= 0:
             hash_name += f"_{SevenHelper.get_now_day_int()}"
         else:
@@ -80,9 +81,10 @@ class AssetBaseModel():
             asset_only_model = AssetOnlyModel(context=self.context)
             asset_only_model.del_entity("only_id=%s", params=[only_id])
 
-    def get_user_asset_id_md5(self, act_id, user_id, asset_type, asset_object_id):
+    def get_user_asset_id_md5(self, app_id, act_id, user_id, asset_type, asset_object_id):
         """
         :description: 生成用户资产唯一标识
+        :param app_id：应用标识
         :param act_id：活动标识
         :param user_id：用户标识
         :param asset_type：资产类型(1-次数2-积分3-价格档位)
@@ -90,10 +92,13 @@ class AssetBaseModel():
         :return: 用户资产唯一标识
         :last_editors: HuangJianYi
         """
-        if not act_id or not user_id or not asset_type:
+        if not user_id or not asset_type:
             return 0
-        return CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}_{asset_type}_{asset_object_id}")
-
+        if act_id > 0:
+            return CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}_{asset_type}_{asset_object_id}")
+        else:
+            return CryptoHelper.md5_encrypt_int(f"{app_id}_0_{user_id}_{asset_type}_{asset_object_id}")
+            
     def get_asset_check_code(self, id_md5, asset_value, sign_key):
         """
         :description: 生成资产校验码
@@ -132,7 +137,7 @@ class AssetBaseModel():
 
         invoke_result_data = InvokeResultData()
 
-        if not act_id or not user_id or not asset_type or not asset_value:
+        if not user_id or not asset_type or not asset_value:
             invoke_result_data.success = False
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "参数不能为空或等于0"
@@ -144,7 +149,7 @@ class AssetBaseModel():
             invoke_result_data.error_message = "资产类型为价格档位,参数asset_object_id不能为空或等于0"
             return invoke_result_data
         asset_value = int(asset_value)
-        user_asset_id_md5 = self.get_user_asset_id_md5(act_id, user_id, asset_type, asset_object_id)
+        user_asset_id_md5 = self.get_user_asset_id_md5(app_id, act_id, user_id, asset_type, asset_object_id)
         if user_asset_id_md5 == 0:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
@@ -155,7 +160,7 @@ class AssetBaseModel():
         is_asset_warn = share_config.get_value("is_asset_warn",False) #是否开启资产预警，跟控制台配套使用
         only_cache_key = ""
         if only_id:
-            only_cache_key = f"asset_only_list:{act_id}_{SevenHelper.get_now_day_int()}"
+            only_cache_key = f"asset_only_list:{act_id}_{SevenHelper.get_now_day_int()}"  if act_id > 0 else f"asset_only_list:{app_id}_0_{SevenHelper.get_now_day_int()}"
             if redis_init.hexists(only_cache_key, only_id):
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
@@ -272,7 +277,11 @@ class AssetBaseModel():
 
             if only_id:
                 asset_only = AssetOnly()
-                asset_only.id_md5 = CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}_{only_id}")
+                if act_id > 0:
+                    asset_only.id_md5 = CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}_{only_id}")
+                else:
+                    asset_only.id_md5 = CryptoHelper.md5_encrypt_int(f"{app_id}_0_{user_id}_{only_id}")
+
                 asset_only.app_id = app_id
                 asset_only.act_id = act_id
                 asset_only.user_id = user_id
@@ -357,10 +366,10 @@ class AssetBaseModel():
         :return: 返回list
         :last_editors: HuangJianYi
         """
-        if not act_id or not user_ids:
+        if not user_ids:
             return []
-        condition = "act_id=%s"
-        params = [act_id]
+        condition = "app_id=%s and act_id=%s"
+        params = [app_id, act_id]
         if asset_type > 0:
             condition+= " AND asset_type=%s"
             params.append(asset_type)
@@ -394,10 +403,10 @@ class AssetBaseModel():
         :return: 返回list
         :last_editors: HuangJianYi
         """
-        if not act_id or not user_id or not asset_type:
+        if not user_id or not asset_type:
             return None
         user_asset_model = UserAssetModel(sub_table=FrameBaseModel(context=self.context).get_business_sub_table("user_asset_tb",{"app_id":app_id}),context=self.context)
-        user_asset_id_md5 = self.get_user_asset_id_md5(act_id, user_id, asset_type, asset_object_id)
+        user_asset_id_md5 = self.get_user_asset_id_md5(app_id, act_id, user_id, asset_type, asset_object_id)
         user_asset_dict = user_asset_model.get_dict("id_md5=%s", limit="1", params=[user_asset_id_md5])
         if user_asset_dict:
             if share_config.get_value("is_check_asset",True) == True: #是否开启资产校验
@@ -407,7 +416,7 @@ class AssetBaseModel():
                     user_asset_dict["asset_value"] = 0
         return user_asset_dict
 
-    def get_asset_log_list(self, app_id, act_id, asset_type=0, page_size=20, page_index=0, user_id=0, asset_object_id="", start_date="", end_date="", user_nick="", open_id="", source_type=0, source_object_id=None, field="*", is_cache=True, operate_type=-1, page_count_mode="total"):
+    def get_asset_log_list(self, app_id, act_id, asset_type=0, page_size=20, page_index=0, user_id=0, asset_object_id="", start_date="", end_date="", user_nick="", open_id="", source_type=0, source_object_id=None, field="*", is_cache=True, operate_type=-1, page_count_mode="total", module_id=0):
         """
         :description: 获取用户资产流水记录
         :param app_id：应用标识
@@ -426,14 +435,18 @@ class AssetBaseModel():
         :param field：查询字段
         :param is_cache：是否缓存
         :param operate_type：操作类型 （0累计 1消耗）
-        :param page_count_mode: 分页计数模式 total-计算总数(默认) next-计算是否有下一页(bool) none-不计算       
+        :param page_count_mode: 分页计数模式 total-计算总数(默认) next-计算是否有下一页(bool) none-不计算
+        :param module_id: 模块标识
         :return: 
         :last_editors: HuangJianYi
         """
         page_list = []
 
-        condition = "act_id=%s"
-        params = [act_id]
+        condition = "app_id=%s and act_id=%s"
+        params = [app_id, act_id]
+        if module_id != 0:
+            condition += " AND module_id=%s"
+            params.append(module_id)
         if asset_type != 0:
             condition += " AND asset_type=%s"
             params.append(asset_type)
@@ -568,8 +581,8 @@ class AssetBaseModel():
         page_list = []
         total = 0
 
-        condition = "act_id=%s and asset_type=%s"
-        params = [act_id, asset_type]
+        condition = "app_id=%s and act_id=%s"
+        params = [app_id, act_id]
         if asset_type != 0:
             condition += " AND asset_type=%s"
             params.append(asset_type)
@@ -596,10 +609,6 @@ class AssetBaseModel():
             params.append(end_date)
 
         page_list, total = AssetWarnNoticeModel(context=self.context).get_dict_page_list(field, page_index, page_size, condition, order_by="id desc", params=params)
-        if len(page_list) > 0:
-            for item in page_list:
-                if item["app_id"] != app_id:
-                    return [],0
         return page_list, total
 
     def update_store_asset(self, app_id,store_id, store_name, asset_type, asset_value, asset_object_id, source_type, source_object_id, source_object_name, log_title, db_connect_key='db_cloudapp', handler_name="",request_code="", info_json={}):
