@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-03-06 23:17:54
-@LastEditTime: 2023-02-10 10:32:18
+@LastEditTime: 2023-03-24 16:59:12
 @LastEditors: HuangJianYi
 :Description: 数据缓存业务模型
 """
@@ -241,10 +241,7 @@ class CacheModel(BaseModel):
         if order_by and order_by.strip() != '':
             order_by = " ORDER BY " + order_by
 
-        if page_count_mode == "next":
-            page_size = page_size + 1
-
-        limit = f"{str(int(page_index) * int(page_size))},{str(page_size)}"
+        limit = f"{str(int(page_index) * int(page_size))},{str(page_size if page_count_mode != 'next' else page_size+1)}"
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by} LIMIT {limit};"
 
         dependency_key = self.get_dependency_key(str(dependency_key))
@@ -276,9 +273,9 @@ class CacheModel(BaseModel):
                 self.set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
                 return self._BaseModel__row_entity_list(page_list["data"]), row_count
             elif page_count_mode == "next":
-                is_next_page = len(list_row) == page_size
-                if list_row and len(list_row)>0:
-                    list_row = list_row[:page_size-1]
+                is_next_page = len(list_row) == page_size+1
+                if list_row and len(list_row) > 0:
+                    list_row = list_row[:page_size]
                 page_list["data"] = list_row
                 page_list["is_next_page"] = is_next_page
                 self.set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
@@ -532,10 +529,7 @@ class CacheModel(BaseModel):
         if order_by and order_by.strip() != '':
             order_by = " ORDER BY " + order_by
 
-        if page_count_mode == "next":
-            page_size = page_size + 1
-
-        limit = f"{str(int(page_index) * int(page_size))},{str(page_size)}"
+        limit = f"{str(int(page_index) * int(page_size))},{str(page_size if page_count_mode != 'next' else page_size+1)}"
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by} LIMIT {limit}"
         
         dependency_key = self.get_dependency_key(str(dependency_key))
@@ -574,9 +568,9 @@ class CacheModel(BaseModel):
                 self.set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
                 return list_row, row_count
             elif page_count_mode == "next":
-                is_next_page = len(list_row) == page_size
-                if list_row and len(list_row)>0:
-                    list_row = list_row[:page_size-1]
+                is_next_page = len(list_row) == page_size+1
+                if list_row and len(list_row) > 0:
+                    list_row = list_row[:page_size]
                 page_list["data"] = list_row
                 page_list["is_next_page"] = is_next_page
                 self.set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
