@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 10:11:35
-@LastEditTime: 2022-09-27 18:05:09
+@LastEditTime: 2022-10-19 14:49:59
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -31,17 +31,19 @@ class OperationLog:
         self.act_id = 0  # 活动标识
         self.operation_type = 0  # 操作类型：1-add，2-update，3-delete 4-还原 5-复制
         self.title = ""  # 标题
-        self.desc = "" # 描述
+        self.operation_desc = "" # 描述
         self.detail = ""  # 当前信息
         self.update_detail = ""  # 更新之后的信息
         self.request_params = ""  # 传入的参数
         self.model_name = ""  # 模块或表名称
+        self.operation_ways = 1  # 操作方式(1单一操作2批量操作)
         self.protocol = ""  # protocol(http或https)
         self.method = ""  # method
         self.handler_name = ""  # handler_name
         self.request_host = ""  # request_host
         self.request_uri = ""  # request_uri
         self.remote_ip = ""  # remote_ip
+        self.request_code = "" # 请求代码
         self.operate_user_id = ""  # 操作人标识
         self.operate_user_name = ""  # 操作人名称
         self.operate_role_id = ""  # 操作角色标识
@@ -51,7 +53,7 @@ class OperationLog:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'app_id', 'act_id', 'operation_type', 'title', 'desc', 'detail', 'update_detail', 'request_params', 'model_name', 'protocol', 'method', 'handler_name', 'request_host', 'request_uri', 'remote_ip', 'operate_user_id', 'operate_user_name', 'operate_role_id', 'create_date', 'create_day']
+        return ['id', 'app_id', 'act_id', 'operation_type', 'title', 'operation_desc', 'detail', 'update_detail', 'request_params', 'model_name', 'operation_ways', 'protocol', 'method', 'handler_name', 'request_host', 'request_uri', 'remote_ip', 'request_code', 'operate_user_id', 'operate_user_name', 'operate_role_id', 'create_date', 'create_day']
 
     @classmethod
     def get_primary_key(self):
