@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-12-20 16:07:52
-@LastEditTime: 2023-02-14 11:56:59
+@LastEditTime: 2023-03-21 09:43:51
 @LastEditors: HuangJianYi
 @Description: 中台接口相关处理业务模型
 """
@@ -19,16 +19,19 @@ class MPBaseModel():
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
 
-    def get_public_function_list(self, project_code):
+    def get_public_function_list(self, project_code, return_response_status=False):
         """
         :description:  获取公共功能列表
         :param project_code:收费项目代码（服务管理-收费项目列表）
+        :param return_response_status:是否返回响应状态
         :return list: 
         :last_editors: HuangJianYi
         """
-
+        response_status = False
         public_function_list = []
         if not project_code:
+            if return_response_status:
+                return public_function_list,response_status
             return public_function_list
         #产品id
         product_id = config.get_value("project_name")
@@ -36,6 +39,8 @@ class MPBaseModel():
         if power_project_id:
             product_id = power_project_id
         if not product_id:
+            if return_response_status:
+                return public_function_list,response_status
             return public_function_list
         requst_url = share_config.get_value("mp_url","http://taobao-mp-s.gao7.com") + "/general/project_code_list"
         data = {}
@@ -46,15 +51,20 @@ class MPBaseModel():
             obj_data = SevenHelper.json_loads(result.text)
             if obj_data and obj_data["Data"]:
                 public_function_list = obj_data["Data"]
+                response_status = True
+        if return_response_status:
+                return public_function_list,response_status
         return public_function_list
 
-    def get_custom_function_list(self, store_user_nick):
+    def get_custom_function_list(self, store_user_nick, return_response_status=False):
         """
         :description:  获取定制功能列表，权限产品id（power_project_id）,SaaS定制走power_project_id必须配置，SaaS可不配置走project_name,对应中台表function_product_tb的app_id字段
         :param store_user_nick:商家主账号昵称
+        :param return_response_status:是否返回响应状态
         :return list: 
         :last_editors: HuangJianYi
         """
+        response_status = False
         custom_function_list = []
         #产品id
         product_id = config.get_value("project_name")
@@ -62,6 +72,8 @@ class MPBaseModel():
         if power_project_id:
             product_id = power_project_id
         if not product_id:
+            if return_response_status:
+                return custom_function_list,response_status
             return custom_function_list
         requst_url = share_config.get_value("mp_url", "http://taobao-mp-s.gao7.com") + "/custom/query_skin_managemen_list"
         data = {}
@@ -72,18 +84,23 @@ class MPBaseModel():
             obj_data = SevenHelper.json_loads(result.text)
             if obj_data and obj_data["Data"]:
                 custom_function_list = obj_data["Data"]
+                response_status = True
+        if return_response_status:
+                return custom_function_list,response_status
         return custom_function_list
     
-    def get_key_power_list(self, store_user_nick, project_code, key_names, user_type=0):
+    def get_key_power_list(self, store_user_nick, project_code, key_names, user_type=0, return_response_status=False):
         """
         :description:  指定模块权限列表，权限产品id（power_project_id）,SaaS定制走power_project_id必须配置，SaaS可不配置走project_name,对应中台表function_product_tb的app_id字段
         :param store_user_nick:商家主账号昵称
         :param project_code:项目编码
         :param key_names:权限代码，多个逗号分隔
         :param user_type:0-不限1-SAAS用户2-SAAS定制用户
+        :param return_response_status:是否返回响应状态
         :return list: 
         :last_editors: HuangJianYi
         """
+        response_status = False
         power_list = []
         #产品id
         product_id = config.get_value("project_name")
@@ -91,6 +108,8 @@ class MPBaseModel():
         if power_project_id:
             product_id = power_project_id
         if not product_id:
+            if return_response_status:
+                return power_list,response_status
             return power_list
         requst_url = share_config.get_value("mp_url", "http://taobao-mp-s.gao7.com") + "/general/jurisdiction_list"
         data = {}
@@ -105,22 +124,32 @@ class MPBaseModel():
             obj_data = SevenHelper.json_loads(result.text)
             if obj_data and obj_data["Data"]:
                 power_list = obj_data["Data"]
+                response_status = True
+        if return_response_status:
+                return power_list,response_status
         return power_list
     
-    def check_high_power(self, store_user_nick, project_code, key_names, user_type=0):
+    def check_high_power(self, store_user_nick, project_code, key_names, user_type=0, return_response_status=False):
         """
         :description:  检验是否有指定模块的权限
         :param store_user_nick:商家主账号昵称
         :param project_code:项目编码
         :param key_names:权限代码，多个逗号分隔 
         :param user_type:0-不限1-SAAS用户2-SAAS定制用户
+        :param return_response_status:是否返回响应状态
         :return bool: 是否有权限
         :last_editors: HuangJianYi
         """
-        power_list = self.get_key_power_list(store_user_nick, project_code, key_names, user_type)
+        response_status = False
+        if return_response_status == True:
+            power_list, response_status = self.get_key_power_list(store_user_nick, project_code, key_names, user_type, return_response_status)
+        else:
+            power_list = self.get_key_power_list(store_user_nick, project_code, key_names, user_type)
         is_power = True    
         for key in power_list:
             if key["is_power"] == False:
                 is_power = False
                 break
+        if return_response_status == True:
+            return is_power,response_status
         return is_power
\ No newline at end of file
