@@ -152,7 +152,7 @@ class OperateBaseModel():
             operation_log = self.get_contrast_info(operation_log, is_all_fields)
         return operation_log
     
-    def _convert_remark(self,config_field, value):
+    def _convert_remark(self, config_field, value):
         """
         :description:  转换备注
         :param config_field:配置字段
@@ -206,39 +206,40 @@ class OperateBaseModel():
                         old_value_remark = ""
                         new_value_remark = ""
                         config_list = SevenHelper.json_loads(operation_config["config_json"]) if operation_config["config_json"] else {}
-                        config_field =  query(config_list).where(lambda x: x["field"] == key).first_or_default(None)
-                        if not config_field or config_field.get("is_show",1) == 0:
-                            continue
-                        old_value = str(operation_log["detail"].get(key, ""))
-                        new_value = str(operation_log["update_detail"].get(key, ""))
-                        old_value_remark = self._convert_remark(config_field, old_value)
-                        new_value_remark = self._convert_remark(config_field, new_value)
-                        sort_index = config_list.index(config_field)
-                        if is_all_fields == True:
-                            info = {}
-                            info["field"] = key
-                            info["out_ways"] = config_field.get("out_ways",0)
-                            info["sort_index"] = config_field.get("sort_index",sort_index)
-                            info["old_value"] = old_value
-                            info["new_value"] = new_value
-                            info["is_update"] = 1 if info["old_value"] != info["new_value"] else 0
-                            info["remark"] = config_field.get("remark","-")
-                            info["old_value_remark"] = old_value_remark
-                            info["new_value_remark"] = new_value_remark
-                            operation_log["contrast_info"].append(info)
-                        else:
-                            if new_value != old_value:
+                        config_fields =  query(config_list).where(lambda x: x["field"] == key).to_list()
+                        for config_field in config_fields:
+                            if config_field.get("is_show",1) == 0:
+                                continue
+                            old_value = str(operation_log["detail"].get(key, ""))
+                            new_value = str(operation_log["update_detail"].get(key, ""))
+                            old_value_remark = self._convert_remark(config_field, old_value)
+                            new_value_remark = self._convert_remark(config_field, new_value)
+                            sort_index = config_list.index(config_field)
+                            if is_all_fields == True:
                                 info = {}
                                 info["field"] = key
                                 info["out_ways"] = config_field.get("out_ways",0)
                                 info["sort_index"] = config_field.get("sort_index",sort_index)
                                 info["old_value"] = old_value
                                 info["new_value"] = new_value
-                                info["is_update"] = 1
-                                info["remark"] = config_field.get("remark", "-")
+                                info["is_update"] = 1 if info["old_value"] != info["new_value"] else 0
+                                info["remark"] = config_field.get("remark","-")
                                 info["old_value_remark"] = old_value_remark
                                 info["new_value_remark"] = new_value_remark
                                 operation_log["contrast_info"].append(info)
+                            else:
+                                if new_value != old_value:
+                                    info = {}
+                                    info["field"] = key
+                                    info["out_ways"] = config_field.get("out_ways",0)
+                                    info["sort_index"] = config_field.get("sort_index",sort_index)
+                                    info["old_value"] = old_value
+                                    info["new_value"] = new_value
+                                    info["is_update"] = 1
+                                    info["remark"] = config_field.get("remark", "-")
+                                    info["old_value_remark"] = old_value_remark
+                                    info["new_value_remark"] = new_value_remark
+                                    operation_log["contrast_info"].append(info)
         except Exception as ex:
             if self.context:
                 self.context.logging_link_error("【获取操作日志对比信息】" + traceback.format_exc())
