@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2023-02-21 09:58:12
+@LastEditTime: 2023-03-09 18:53:01
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -196,19 +196,20 @@ class OrderBaseModel(FrameBaseModel):
                 update_sql = "order_status=1,express_company=%s,express_no=%s,deliver_date=%s,modify_date=%s"
                 params = [express_company, express_no, now_datetime, now_datetime, prize_order_id]
                 prize_order_model.update_table(update_sql, "id=%s", params)
-                prize_roster_model.update_table("logistics_status=1", "act_id=%s and order_no=%s", [prize_order.act_id,prize_order.order_no])
+                prize_roster_model.update_table("logistics_status=1", "order_no=%s", [prize_order.order_no])
             elif order_status == 2:
                 update_sql = "order_status=2,modify_date=%s"
                 params = [now_datetime, prize_order_id]
                 prize_order_model.update_table(update_sql, "id=%s", params)
-                prize_roster_model.update_table("logistics_status=2", "act_id=%s and order_no=%s", [prize_order.act_id,prize_order.order_no])
+                prize_roster_model.update_table("logistics_status=2", "order_no=%s", [prize_order.order_no])
             else:
                 prize_order_model.update_table("order_status=%s,modify_date=%s", "id=%s", [order_status, now_datetime, prize_order_id])
                 if order_status == 0:
-                    prize_roster_model.update_table("logistics_status=0", "act_id=%s and order_no=%s", [prize_order.act_id,prize_order.order_no])
+                    prize_roster_model.update_table("logistics_status=0", "order_no=%s", [prize_order.order_no])
             result,message = db_transaction.commit_transaction(True)
             if result == False:
                 raise Exception("执行事务失败",message)
+            prize_order_model.delete_dependency_key(DependencyKey.prize_order_list(prize_order.act_id,prize_order.user_id))
 
         except Exception as ex:
             if self.context:
@@ -323,11 +324,7 @@ class OrderBaseModel(FrameBaseModel):
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        if not act_id:
-            invoke_result_data.success = False
-            invoke_result_data.error_code = "error"
-            invoke_result_data.error_message ="无效活动,无法导入订单"
-            return invoke_result_data
+
         prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb",{"app_id":app_id}),context=self.context)
         if not prize_roster_sub_table:
             prize_roster_sub_table = self.get_business_sub_table("prize_roster_tb",{"app_id":app_id})
@@ -373,10 +370,10 @@ class OrderBaseModel(FrameBaseModel):
                 if order_no and express_no and express_company:
                     now_datetime = SevenHelper.get_now_datetime()
                     update_sql = "order_status=1,express_company=%s,express_no=%s,deliver_date=%s"
-                    params = [express_company, express_no, now_datetime, app_id,act_id,order_no]
-                    result = prize_order_model.update_table(update_sql, "app_id=%s and act_id=%s and order_no=%s", params)
+                    params = [express_company, express_no, now_datetime, order_no]
+                    result = prize_order_model.update_table(update_sql, "order_no=%s", params)
                     if result == True:
-                        prize_roster_model.update_table("logistics_status=1", "app_id=%s and act_id=%s and order_no=%s", [app_id,act_id,order_no])
+                        prize_roster_model.update_table("logistics_status=1", "order_no=%s", [order_no])
                         total_num += 1
             os.remove(path)
         else:
@@ -388,16 +385,13 @@ class OrderBaseModel(FrameBaseModel):
                 if order_no and express_no and express_company:
                     now_datetime = SevenHelper.get_now_datetime()
                     update_sql = "order_status=1,express_company=%s,express_no=%s,deliver_date=%s"
-                    params = [express_company, express_no, now_datetime, app_id,act_id,order_no]
-                    result = prize_order_model.update_table(update_sql, "app_id=%s and act_id=%s and order_no=%s", params)
+                    params = [express_company, express_no, now_datetime, order_no]
+                    result = prize_order_model.update_table(update_sql, "order_no=%s", params)
                     if result == True:
-                        prize_roster_model.update_table("logistics_status=1", "app_id=%s and act_id=%s and order_no=%s", [app_id,act_id,order_no])
+                        prize_roster_model.update_table("logistics_status=1", "order_no=%s", [order_no])
                         total_num += 1
                 else:
-                    invoke_result_data.success = False
-                    invoke_result_data.error_code = "error"
-                    invoke_result_data.error_message = "缺少必要字段，无法导入订单"
-                    return invoke_result_data
+                    continue
         invoke_result_data.data = {"total_num": total_num}
         return invoke_result_data
 
@@ -420,13 +414,8 @@ class OrderBaseModel(FrameBaseModel):
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        if not act_id:
-            invoke_result_data.success = False
-            invoke_result_data.error_code = "error"
-            invoke_result_data.error_message ="无效活动,无法创建订单"
-            return invoke_result_data
+
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"),context=self.context)
-        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb",{"app_id":app_id}), db_transaction=db_transaction, context=self.context)
         prize_roster_model = PrizeRosterModel(sub_table=self.get_business_sub_table("prize_roster_tb",{"app_id":app_id}), db_transaction=db_transaction, context=self.context)
         prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb",{"app_id":app_id}),db_transaction=db_transaction, context=self.context)
         prize_ids_list = []
@@ -442,24 +431,26 @@ class OrderBaseModel(FrameBaseModel):
                     return invoke_result_data
 
         #获取用户信息
-        user_info_dict = user_info_model.get_dict("act_id=%s and user_id=%s", limit="1", params=[act_id, user_id])
-        if not user_info_dict:
-            invoke_result_data.success = False
-            invoke_result_data.error_code = "error"
-            invoke_result_data.error_message = "用户不存在"
-            return invoke_result_data
-        if user_info_dict["login_token"] != login_token:
-            invoke_result_data.success = False
-            invoke_result_data.error_code = "error"
-            invoke_result_data.error_message = "已在另一台设备登录,无法操作"
-            return invoke_result_data
-        if int(user_info_dict["user_state"]) == 1:
-            invoke_result_data.success = False
-            invoke_result_data.error_code = "user_exception"
-            invoke_result_data.error_message = "账号异常,请联系客服处理"
-            return invoke_result_data
-
-        acquire_lock_name = f"create_prize_order_queue_{act_id}_{user_id}"
+        if act_id > 0 :
+            user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb",{"app_id":app_id}), context=self.context)
+            user_info_dict = user_info_model.get_dict("act_id=%s and user_id=%s", limit="1", params=[act_id, user_id])
+            if not user_info_dict:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message = "用户不存在"
+                return invoke_result_data
+            if user_info_dict["login_token"] != login_token:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message = "已在另一台设备登录,无法操作"
+                return invoke_result_data
+            if int(user_info_dict["user_state"]) == 1:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "user_exception"
+                invoke_result_data.error_message = "账号异常,请联系客服处理"
+                return invoke_result_data
+        
+        acquire_lock_name = f"create_prize_order_queue_{act_id}_{user_id}" if act_id > 0 else f"create_prize_order_queue_{app_id}_0_{user_id}"
         acquire_lock_status, identifier = SevenHelper.redis_acquire_lock(acquire_lock_name)
         if acquire_lock_status == False:
             invoke_result_data.success = False
@@ -469,7 +460,7 @@ class OrderBaseModel(FrameBaseModel):
             return invoke_result_data
         #用户奖品列表
         if len(prize_ids_list)>0:
-            prize_roster_list = prize_roster_model.get_list("act_id=%s and user_id=%s and id in (" + prize_ids + ") and prize_status=0",params=[act_id, user_id])
+            prize_roster_list = prize_roster_model.get_list("app_id=%s and act_id=%s and user_id=%s and prize_status=0 and id in (" + prize_ids + ")",params=[app_id, act_id, user_id])
             if len(prize_roster_list) == 0:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
@@ -477,7 +468,7 @@ class OrderBaseModel(FrameBaseModel):
                 SevenHelper.redis_release_lock(acquire_lock_name, identifier)
                 return invoke_result_data
         else:
-            prize_roster_list = prize_roster_model.get_list("act_id=%s and user_id=%s and prize_status=0",params=[act_id, user_id])
+            prize_roster_list = prize_roster_model.get_list("app_id=%s and act_id=%s and user_id=%s and prize_status=0",params=[app_id, act_id, user_id])
 
         now_date = SevenHelper.get_now_datetime()
         prize_order = PrizeOrder()
@@ -821,50 +812,50 @@ class OrderBaseModel(FrameBaseModel):
         :last_editors: HuangJianYi
         """
         condition_where = ConditionWhere()
-        condition_where.add_condition( "app_id=%s")
+        condition_where.add_condition("app_id=%s")
         params_list = [app_id]
         if act_id >= 0:
-            condition_where.add_condition( "act_id=%s")
+            condition_where.add_condition("act_id=%s")
             params_list.append(act_id)
-        if condition:
-            condition_where.add_condition( "condition=%s")
-            params_list.extend(params)
         if module_id:
-            condition_where.add_condition( "module_id=%s")
+            condition_where.add_condition("module_id=%s")
             params_list.append(module_id)
         if user_id:
-            condition_where.add_condition( "user_id=%s")
+            condition_where.add_condition("user_id=%s")
             params_list.append(user_id)
         if open_id:
-            condition_where.add_condition( "open_id=%s")
+            condition_where.add_condition("open_id=%s")
             params_list.append(open_id)
         if user_nick:
-            condition_where.add_condition( "user_nick=%s")
+            condition_where.add_condition("user_nick=%s")
             params_list.append(user_nick)
         if order_no:
-            condition_where.add_condition( "order_no=%s")
+            condition_where.add_condition("order_no=%s")
             params_list.append(order_no)
         if goods_type !=-1:
-            condition_where.add_condition( "goods_type=%s")
+            condition_where.add_condition("goods_type=%s")
             params_list.append(goods_type)
         if prize_type !=-1:
-            condition_where.add_condition( "prize_type=%s")
+            condition_where.add_condition("prize_type=%s")
             params_list.append(prize_type)
         if logistics_status !=-1:
-            condition_where.add_condition( "logistics_status=%s")
+            condition_where.add_condition("logistics_status=%s")
             params_list.append(logistics_status)
         if prize_status !=-1:
-            condition_where.add_condition( "prize_status=%s")
+            condition_where.add_condition("prize_status=%s")
             params_list.append(prize_status)
         if pay_status !=-1:
-            condition_where.add_condition( "pay_status=%s")
+            condition_where.add_condition("pay_status=%s")
             params_list.append(pay_status)
         if create_date_start:
-            condition_where.add_condition( "create_date>=%s")
+            condition_where.add_condition("create_date>=%s")
             params_list.append(create_date_start)
         if create_date_end:
-            condition_where.add_condition( "create_date<=%s")
+            condition_where.add_condition("create_date<=%s")
             params_list.append(create_date_end)
+        if condition:
+            condition_where.add_condition(condition)
+            params_list.extend(params)
 
         prize_roster_model = PrizeRosterModel(sub_table=self.get_business_sub_table("prize_roster_tb",{"app_id":app_id}),context=self.context)
         if is_cache:
@@ -887,8 +878,11 @@ class OrderBaseModel(FrameBaseModel):
         :last_editors: HuangJianYi
         """
         condition_where = ConditionWhere()
-        condition_where.add_condition("act_id=%s")
-        params_list = [act_id]
+        condition_where.add_condition("app_id=%s")
+        params_list = [app_id]
+        if act_id >= 0:
+            condition_where.add_condition("act_id=%s")
+            params_list.append(act_id)
         if is_search_module == True and module_id:
             condition_where.add_condition("module_id=%s")
             params_list.append(module_id)
@@ -989,9 +983,8 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message ="未授权请联系客服授权"
             return invoke_result_data
-        dependency_key = f"prize_roster_list:actid_{act_id}_userid_{user_id}"
         prize_roster_model = PrizeRosterModel(sub_table=self.get_business_sub_table("prize_roster_tb",{"app_id":app_id}),context=self.context)
-        prize_roster_dict = prize_roster_model.get_cache_dict_by_id(user_prize_id, dependency_key=dependency_key)
+        prize_roster_dict = prize_roster_model.get_cache_dict_by_id(user_prize_id, dependency_key=DependencyKey.prize_roster_list(act_id,user_id))
         if not prize_roster_dict or prize_roster_dict['user_id'] != user_id or prize_roster_dict['act_id'] != act_id:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
@@ -1015,14 +1008,14 @@ class OrderBaseModel(FrameBaseModel):
         if resp["alibaba_benefit_send_response"]:
             if resp["alibaba_benefit_send_response"]["result_success"] == True:
                 prize_roster_model.update_table("prize_status=1", "id=%s", params=[user_prize_id])
-                prize_roster_model.delete_dependency_key(dependency_key)
+                prize_roster_model.delete_dependency_key(DependencyKey.prize_roster_list(act_id,user_id))
                 result = {}
                 result["prize_name"] = resp["alibaba_benefit_send_response"]["prize_name"]
                 invoke_result_data.data = result
                 return invoke_result_data
             if resp["alibaba_benefit_send_response"]["result_code"] == "COUPON_INVALID_OR_DELETED":
                 prize_roster_model.update_table("prize_status=10", "id=%s", params=[user_prize_id])
-                prize_roster_model.delete_dependency_key(dependency_key)
+                prize_roster_model.delete_dependency_key(DependencyKey.prize_roster_list(act_id,user_id))
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
                 invoke_result_data.error_message ="领取失败：优惠券无效或已删除"
