@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 15:44:04
-@LastEditTime: 2023-02-10 10:38:55
+@LastEditTime: 2023-03-13 11:31:44
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -149,7 +149,7 @@ class ThemeBaseModel():
             ActModuleModel(context=self.context).update_table("skin_id=%s", "act_id=%s", [skin_info.id, act_id])
         return invoke_result_data
 
-    def save_theme(self, app_id, theme_name, client_json, server_json, out_id, ver_no, style_type):
+    def save_theme(self, app_id, theme_name, client_json, server_json, out_id, ver_no, style_type, ascription_type=1):
         """
         :description: 添加或修改主题
         :param app_id：app_id
@@ -159,6 +159,7 @@ class ThemeBaseModel():
         :param out_id：外部id
         :param ver_no：客户端版本号
         :param style_type：样式类型
+        :param ascription_type：归属类型(1公共)
         :return: 
         :last_editors: HuangJianYi
         """
@@ -200,6 +201,7 @@ class ThemeBaseModel():
             theme_info.server_json = server_json
             theme_info.out_id = out_id
             theme_info.style_type = style_type
+            theme_info.ascription_type = ascription_type
             if app_id != "":
                 theme_info.app_id = app_id
                 theme_info.is_private = 1
